@@ -85,7 +85,7 @@ new CloudFrontToApiGateway(scope: Construct, id: string, props: CloudFrontToApiG
 |:-------------|:----------------|-----------------|
 |cloudFrontWebDistribution|[`cloudfront.CloudFrontWebDistribution`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.CloudFrontWebDistribution.html)|Returns an instance of cloudfront.CloudFrontWebDistribution created by the construct|
 |apiGateway|[`api.RestApi`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.RestApi.html)|Returns an instance of the API Gateway REST API created by the pattern.|
-|edgeLambdaFunctionVersion|[`lambda.Version`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Version.html)|Returns an instance of the edge Lambda function version created by the pattern.|
+|cloudFrontFunction?|[`cloudfront.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudfront.Function.html)|Returns an instance of the Cloudfront function created by the pattern.|
 |cloudFrontLoggingBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/aws-s3-readme.html)|Returns an instance of the logging bucket for CloudFront WebDistribution.|
 
 ## Default settings
@@ -125,7 +125,6 @@ from ._jsii import *
 
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_cloudfront
-import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
 import aws_cdk.core
 
@@ -173,18 +172,16 @@ class CloudFrontToApiGateway(
     def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cloudFrontFunction")
+    def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
+        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="edgeLambdaFunctionVersion")
-    def edge_lambda_function_version(
-        self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.Version]:
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Version], jsii.get(self, "edgeLambdaFunctionVersion"))
-
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGatewayProps",
